@@ -107,11 +107,9 @@ __global__ void get_cov(int cols, int total_rows, float *d_A, float *d_means, fl
 func = mod.get_function("get_cov")
 
 
-def get_cov(df):
+def get_cov(A):
 
-    df = df.astype(np.float32)
-
-    rows, cols = df.shape
+    rows, cols = A.shape
     rows = int(rows)
     cols = int(cols)
 
@@ -122,9 +120,6 @@ def get_cov(df):
     covariances = np.zeros(cols * cols)
     covariances = covariances.astype(np.float32)
 
-    A = df.values
-    A = A.astype(np.float32)
-
     # Allocate on device
     d_A = cuda.mem_alloc(A.size * A.dtype.itemsize)
     d_means = cuda.mem_alloc(means.size * means.dtype.itemsize)
@@ -161,8 +156,10 @@ def get_cov(df):
 
     # Return Covariance Matrix
     return np.resize(covariances, (cols, cols))
+    # return covariances
 
 
+# Test funciton
 def hello():
     print("Hello Ivan and World")
 
